<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AudioCart</name>
    <message>
        <source>Copying audio...</source>
        <translation>Copiando audio...</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>WT</source>
        <translation type="obsolete">WT</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">DESCRIPCIÓN</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">DURACIÓN</translation>
    </message>
    <message>
        <source>LAST PLAYED</source>
        <translation type="obsolete">ÚLTIMA REPROD</translation>
    </message>
    <message>
        <source># OF PLAYS</source>
        <translation type="obsolete"># DE REPROD</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation type="obsolete">ORIGEN</translation>
    </message>
    <message>
        <source>OUTCUE</source>
        <translation type="obsolete">OUTCUE</translation>
    </message>
    <message>
        <source>START DATE</source>
        <translation type="obsolete">FECHA INICIO</translation>
    </message>
    <message>
        <source>END DATE</source>
        <translation type="obsolete">FECHA FIN</translation>
    </message>
    <message>
        <source>DAYPART START</source>
        <translation type="obsolete">INICIO DE DAYPART</translation>
    </message>
    <message>
        <source>DAYPART END</source>
        <translation type="obsolete">FIN DE DAYPART</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="obsolete">NOMBRE</translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation type="obsolete">Audios</translation>
    </message>
    <message>
        <source>Cut Info</source>
        <translation>Info. audio</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Grabar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation>¿Desea eliminar </translation>
    </message>
    <message>
        <source>Delete Cut</source>
        <translation>Eliminar audio</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Vaciar portapapeles</translation>
    </message>
    <message>
        <source>Deleting this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Eliminando este audio también dejará el portapapeles vacío.
¿Desea continuar la eliminación?</translation>
    </message>
    <message>
        <source>Clipboard Empty</source>
        <translation>Portapapeles vacío</translation>
    </message>
    <message>
        <source>Clipboard is currently empty.</source>
        <translation>El portapapeles está vacío.</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>1 Cut</source>
        <translation type="obsolete">1 audio</translation>
    </message>
    <message>
        <source>[new cart]</source>
        <translation>[nuevo cartucho]</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>This cut is used in one or more RDCatch events!
Do you still want to delete it?</source>
        <translation type="obsolete">¡Este audio está en uso por uno o más eventos de RDCatch!
¿Desea eliminarlo de todas formas?</translation>
    </message>
    <message>
        <source>RDCatch Event Exists</source>
        <translation>Ya existe un evento RDCatch</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>El audio existe</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Esto sobreescribirá la grabación existente.
¿Desea continuar?</translation>
    </message>
    <message>
        <source>Edit
Markers</source>
        <translation>Editar
Marcadores</translation>
    </message>
    <message>
        <source>Rip CD</source>
        <translation>Leer CD</translation>
    </message>
    <message>
        <source>Edit
Audio</source>
        <translation>Editar
Audio</translation>
    </message>
    <message>
        <source>RDLibrary</source>
        <translation>RDLibrary</translation>
    </message>
    <message>
        <source>Unable to delete audio!</source>
        <translation type="obsolete">¡No se pudo eliminar el audio!</translation>
    </message>
    <message>
        <source>No audio is present in the cut!</source>
        <translation>¡No hay audios en este cut!</translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One or more cuts are used in one or more RDCatch events!
Do you still want to delete?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete audio for cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No data copied - you must select a single cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must select a single cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Played</source>
        <translation type="unfinished">Últ. Reprod</translation>
    </message>
    <message>
        <source># of Plays</source>
        <translation type="unfinished"># de reprod</translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ingest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outcue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daypart Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daypart End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ord</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CdRipper</name>
    <message>
        <source>Artist:</source>
        <translation>Artista:</translation>
    </message>
    <message>
        <source>Album:</source>
        <translation>Álbum:</translation>
    </message>
    <message>
        <source>Other:</source>
        <translation>Otro:</translation>
    </message>
    <message>
        <source>Apply FreeDB Values to Cart</source>
        <translation>Usar datos obtenidos de FreeDB</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Pistas</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>PISTA</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>DURACIÓN</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TÍTULO</translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation>OTROS</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TIPO</translation>
    </message>
    <message>
        <source>&amp;Rip
Track</source>
        <translation>Lee&amp;r
Pista</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizar</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autorecorte</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Canales:</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Vaciar portapapeles</translation>
    </message>
    <message>
        <source>Ripping this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Leyendo este audio también vaciará el portapapeles.
¿Desea continuar?</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Sin acceso</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">No se puede abrir el archivo para escribir en él</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">Aceptar</translation>
    </message>
    <message>
        <source>Audio Track</source>
        <translation>Pista de audio</translation>
    </message>
    <message>
        <source>Data Track</source>
        <translation>Pista de datos</translation>
    </message>
    <message>
        <source>Rip Complete</source>
        <translation>Lectura completada</translation>
    </message>
    <message>
        <source>Rip complete!</source>
        <translation>¡Lectura completada!</translation>
    </message>
    <message>
        <source>Rip Aborted</source>
        <translation type="obsolete">Lectura cancelada</translation>
    </message>
    <message>
        <source>The rip has been aborted.</source>
        <translation type="obsolete">La lectura ha sido cancelada.</translation>
    </message>
    <message>
        <source>Rip Failed</source>
        <translation type="obsolete">La lectura falló</translation>
    </message>
    <message>
        <source>The ripper encountered an error.
Please check your ripper configuration and try again.</source>
        <translation type="obsolete">El lector de CD encontró un error.
Por favor, chequee la configuración e intente de nuevo.</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Esta acción sobreescribirá la grabación existente.
¿Desea continuar?</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>El audio ya existe</translation>
    </message>
    <message>
        <source>RDLibrary - Importer Error</source>
        <translation>RDLibrary - Error al importar</translation>
    </message>
    <message>
        <source>RDLibrary - Ripper Error</source>
        <translation>RDLibrary - Error al leer</translation>
    </message>
    <message>
        <source>Abort
Rip</source>
        <translation>Abortar
Lectura</translation>
    </message>
    <message>
        <source>Rip Track</source>
        <translation type="obsolete">Leyendo pista</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create temporary directory!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip CD</source>
        <translation type="unfinished">Leer CD</translation>
    </message>
    <message>
        <source>Rip
Track</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DiskGauge</name>
    <message>
        <source>Free</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DiskRipper</name>
    <message>
        <source>Artist:</source>
        <translation>Artista:</translation>
    </message>
    <message>
        <source>Album:</source>
        <translation>Álbum:</translation>
    </message>
    <message>
        <source>Other:</source>
        <translation>Otros:</translation>
    </message>
    <message>
        <source>Apply FreeDB Values to Carts</source>
        <translation>Usar información de FreeDB</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Pistas</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>PISTA</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>DURACIÓN</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TÍTULO</translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation>OTROS</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TIPO</translation>
    </message>
    <message>
        <source>CUT</source>
        <translation>AUDIO</translation>
    </message>
    <message>
        <source>Disk Progress</source>
        <translation>Progreso en el Disco</translation>
    </message>
    <message>
        <source>Track Progress</source>
        <translation>Progreso en la pista</translation>
    </message>
    <message>
        <source>Set
&amp;Cut</source>
        <translation type="obsolete">Asignar
&amp;Audio</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizar</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autorecorte</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Canales:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Cut Conflict</source>
        <translation>Conflicto en los audios</translation>
    </message>
    <message>
        <source>That cut has already been assigned a track!</source>
        <translation>Este audio ya había sido asignado a una pista</translation>
    </message>
    <message>
        <source>Cut Exists</source>
        <translation>El audio ya existe</translation>
    </message>
    <message>
        <source>A recording already exists.
Do you want to overwrite it?</source>
        <translation>Ya hay una grabación.
¿Desea sobreescribirla?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Portapapeles vacío</translation>
    </message>
    <message>
        <source>Ripping this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Al leer el disco se vaciará el portapapeles.
¿Desea continuar?</translation>
    </message>
    <message>
        <source>Audio Track</source>
        <translation>Pista de audio</translation>
    </message>
    <message>
        <source>Data Track</source>
        <translation>Pista de datos</translation>
    </message>
    <message>
        <source>Rip Complete</source>
        <translation>Lectura completada</translation>
    </message>
    <message>
        <source>Rip complete!</source>
        <translation>¡Lectura completada!</translation>
    </message>
    <message>
        <source>Rip Aborted</source>
        <translation type="obsolete">Lectura cancelada</translation>
    </message>
    <message>
        <source>The rip has been aborted.</source>
        <translation type="obsolete">La lectura ha sido cancelada.</translation>
    </message>
    <message>
        <source>Rip Failed</source>
        <translation type="obsolete">La lectura falló.</translation>
    </message>
    <message>
        <source>The ripper encountered an error.
Please check your ripper configuration and try again.</source>
        <translation type="obsolete">El lector encontró un error.
Por favor, chequee la configuración e intente de nuevo.</translation>
    </message>
    <message>
        <source>Total Progress</source>
        <translation>Progreso total</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Sin acceso</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">No es posible escribir en el archivo.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">Aceptar</translation>
    </message>
    <message>
        <source>Rip Disk</source>
        <translation>Leer disco</translation>
    </message>
    <message>
        <source>Library Error</source>
        <translation type="obsolete">Error en las bibliotecas</translation>
    </message>
    <message>
        <source>Insufficient free carts available in group!</source>
        <translation type="obsolete">No hay suficientes cartuchos disponibles en el grupo.</translation>
    </message>
    <message>
        <source>Set All
&amp;New Carts</source>
        <translation type="obsolete">Crear como
&amp;cartuchos</translation>
    </message>
    <message>
        <source>&amp;Rip
Disc</source>
        <translation>Lee&amp;r
disco</translation>
    </message>
    <message>
        <source>RDLibrary - Importer Error</source>
        <translation>RDLIbrary - Error al importar</translation>
    </message>
    <message>
        <source>RDLibrary - Ripper Error</source>
        <translation>RDLibrary - Error de lectura</translation>
    </message>
    <message>
        <source>Abort
Rip</source>
        <translation>Abortar
Lectura</translation>
    </message>
    <message>
        <source>Rip
Disk</source>
        <translation>Leer
Disco</translation>
    </message>
    <message>
        <source>Rip aborted!</source>
        <translation>¡Lectura
Abortada!</translation>
    </message>
    <message>
        <source>Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create temporary directory!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Cart
Per Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Single
Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set
&amp;Cart/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[continued]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify
Cart Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear
Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to allocate carts in group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to allocate cart in group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditCart</name>
    <message>
        <source>Number:</source>
        <translation>Número:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Enforce Length</source>
        <translation>Forzar duración</translation>
    </message>
    <message>
        <source>Preserve Pitch</source>
        <translation>Preservar pitch</translation>
    </message>
    <message>
        <source>&amp;Title:</source>
        <translation>&amp;Título</translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation>Fecha de &amp;Inicio:</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation>Fecha &amp;Final:</translation>
    </message>
    <message>
        <source>&amp;Artist:</source>
        <translation>&amp;Artista:</translation>
    </message>
    <message>
        <source>Al&amp;bum:</source>
        <translation>Ál&amp;bum:</translation>
    </message>
    <message>
        <source>Re&amp;cord Label:</source>
        <translation>E&amp;tiq. de grabación:</translation>
    </message>
    <message>
        <source>C&amp;lient:</source>
        <translation>C&amp;liente:</translation>
    </message>
    <message>
        <source>A&amp;gency:</source>
        <translation>A&amp;gencia:</translation>
    </message>
    <message>
        <source>&amp;User Defined:</source>
        <translation>&amp;Uso reservado:</translation>
    </message>
    <message>
        <source>Schedule Cuts:</source>
        <translation type="obsolete">Audios programad.:</translation>
    </message>
    <message>
        <source>&amp;Edit
Script</source>
        <translation>&amp;Editar
Script</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>Acepta&amp;r</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>AUDIO</source>
        <translation>AUDIO</translation>
    </message>
    <message>
        <source>MACRO</source>
        <translation>MACRO</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation>DESCONOCIDO</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation>TFN</translation>
    </message>
    <message>
        <source>Sequentially</source>
        <translation type="obsolete">Secuencial</translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation type="obsolete">Aleatorio</translation>
    </message>
    <message>
        <source>Missing Title</source>
        <translation>No hay título</translation>
    </message>
    <message>
        <source>You must provide at least a Cart Title!</source>
        <translation>¡Usted debe indicar al menos un título para el cartucho!</translation>
    </message>
    <message>
        <source>Length Mismatch</source>
        <translation>La duración no concuerda</translation>
    </message>
    <message>
        <source>One or more cut lengths exceed the timescaling
limits of the system!  Do you still want to save?</source>
        <translation>La duración de uno o varios audios exceden
los límites del sistema.  ¿Desea continuar?</translation>
    </message>
    <message>
        <source>Average Length:</source>
        <translation>Duración Promedio:</translation>
    </message>
    <message>
        <source>Forced Length:</source>
        <translation>Duración obligada:</translation>
    </message>
    <message>
        <source>Execute Asynchronously</source>
        <translation>Ejecutar de forma asíncrona</translation>
    </message>
    <message>
        <source>&amp;Year Released:</source>
        <translation>Año de &amp;Publicación:</translation>
    </message>
    <message>
        <source>&amp;Publisher:</source>
        <translation>&amp;Publicador:</translation>
    </message>
    <message>
        <source>Compos&amp;er:</source>
        <translation>Composi&amp;tor:</translation>
    </message>
    <message>
        <source>U&amp;sage:</source>
        <translation>U&amp;so:</translation>
    </message>
    <message>
        <source>Scheduler Codes</source>
        <translation>Códigos musicalizador</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Duplicate Title</source>
        <translation>Título duplicado</translation>
    </message>
    <message>
        <source>The cart title must be unique!</source>
        <translation>¡El título del cartucho debe ser único!</translation>
    </message>
    <message>
        <source>&amp;Edit
Notes</source>
        <translation>&amp;Editar
Notas</translation>
    </message>
    <message>
        <source>RDLibrary - Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cond&amp;uctor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Song &amp;ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Beats per Minute:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By Specified Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By Weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schedule Cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following cut order values are assigned more than once</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Cut Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Carts [multiple]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use RDLogManager Length for PAD Updates</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMacro</name>
    <message>
        <source>Edit Macro</source>
        <translation type="obsolete">Editar macro</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>Acepta&amp;r</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>EditNotes</name>
    <message>
        <source>Notes for cart</source>
        <translation>Notas para el cartucho</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>Acepta&amp;r</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>EditSchedulerCodes</name>
    <message>
        <source>Select Scheduler Codes</source>
        <translation>Elija Códigos para Musicalizar</translation>
    </message>
    <message>
        <source>Available Codes</source>
        <translation>Códigos disponibles</translation>
    </message>
    <message>
        <source>Assigned Codes</source>
        <translation>Códigos Asignados</translation>
    </message>
    <message>
        <source>ASSIGN to Carts</source>
        <translation>ASIGNAR a cartuchos</translation>
    </message>
    <message>
        <source>REMOVE from Carts</source>
        <translation>REMOVER de Cartuchos</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>Acepta&amp;r</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Library Filter</source>
        <translation type="obsolete">Filtro de la biblioteca</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">Acepta&amp;r</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation type="obsolete">&amp;Limpiar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Cancelar</translation>
    </message>
    <message>
        <source>&amp;Filter:</source>
        <translation type="obsolete">&amp;Filtro:</translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation type="obsolete">Reportes de RDLibrary</translation>
    </message>
    <message>
        <source>Cart Report</source>
        <translation>Reporte de Cartuchos</translation>
    </message>
    <message>
        <source>Cut Report</source>
        <translation>Reporte de Audios</translation>
    </message>
    <message>
        <source>Cart Data Dump</source>
        <translation type="obsolete">Vaciado de datos de Cartuchos</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation>&amp;Generar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished">TODAS</translation>
    </message>
    <message>
        <source>Cart Data Dump (CSV)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prepend Field Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MacroCart</name>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>LINE</source>
        <translation type="obsolete">LÍNEA</translation>
    </message>
    <message>
        <source>COMMAND</source>
        <translation type="obsolete">COMANDO</translation>
    </message>
    <message>
        <source>Macros</source>
        <translation>Macros</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Run
Line</source>
        <translation>Ejecutar
línea</translation>
    </message>
    <message>
        <source>Run
Cart</source>
        <translation>Ejecutar
Cartucho</translation>
    </message>
    <message>
        <source>--- End of cart ---</source>
        <translation type="obsolete">--- Fin del cartucho ---</translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--- End of Cart ---</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">No puedo conectar</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Limpiar</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <source>Show Audio Carts</source>
        <translation>Mostrar cart. de audio</translation>
    </message>
    <message>
        <source>Show Macro Carts</source>
        <translation>Mostrar cart. macro</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">CARTUCHO</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">GRUPO</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">DURACIÓN</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">TÍTULO</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">ARTISTA</translation>
    </message>
    <message>
        <source>START</source>
        <translation type="obsolete">INICIO</translation>
    </message>
    <message>
        <source>END</source>
        <translation type="obsolete">FIN</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="obsolete">CLIENTE</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="obsolete">AGENCIA</translation>
    </message>
    <message>
        <source>USER DEFINED</source>
        <translation type="obsolete">RESERVADO</translation>
    </message>
    <message>
        <source>CUTS</source>
        <translation type="obsolete">AUDIOS</translation>
    </message>
    <message>
        <source>LAST CUT PLAYED</source>
        <translation type="obsolete">ÚLT. AUDIO REPR.</translation>
    </message>
    <message>
        <source>PLAY ORDER</source>
        <translation type="obsolete">ORDEN DE REPROD.</translation>
    </message>
    <message>
        <source>ENFORCE LENGTH</source>
        <translation type="obsolete">OBLIGAR DURACIÓN</translation>
    </message>
    <message>
        <source>PRESERVE PITCH</source>
        <translation type="obsolete">PRESERVAR PITCH</translation>
    </message>
    <message>
        <source>LENGTH DEVIATION</source>
        <translation type="obsolete">DESVIACIÓN DE LA DURACIÓN</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Añadir</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>TODAS</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Vaciar portapapeles</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation type="obsolete">Secuencia</translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="obsolete">Aleatorio</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation></translation>
    </message>
    <message>
        <source>RDLibrary - Host:</source>
        <translation type="obsolete">RDLibrary - Servidor: </translation>
    </message>
    <message>
        <source>, User:</source>
        <translation type="obsolete">, Usuario:</translation>
    </message>
    <message>
        <source>&amp;Rip
CD</source>
        <translation>&amp;Leer
CD</translation>
    </message>
    <message>
        <source>OWNED BY</source>
        <translation type="obsolete">PROPIEDAD DE</translation>
    </message>
    <message>
        <source>RDCatch Event Exists</source>
        <translation>Evento RDCatch ya existe</translation>
    </message>
    <message>
        <source>Re&amp;ports</source>
        <translation>Re&amp;porte</translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation>Códs. Musicaliz.:</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Are you sure you want to delete cart(s)</source>
        <translation>¿Está seguro de eliminar el o los cartuchos?</translation>
    </message>
    <message>
        <source>Delete Cart(s)</source>
        <translation>Eliminar cartucho(s)</translation>
    </message>
    <message>
        <source>Cart %06u is used in one or more RDCatch events!
Do you still want to delete it?</source>
        <translation>El cartucho %06u está siendo usado en eventos RDCatch
¿Aún así desea eliminarlos?</translation>
    </message>
    <message>
        <source>Deleting cart %06u will also empty the clipboard.
      	Do you still want to proceed?</source>
        <translation>Al eliminar el cartucho %06u también se vaciará el portapapeles.
      	¿Desea continuar?</translation>
    </message>
    <message>
        <source>rdlibrary : </source>
        <translation type="obsolete">rdlibrary : </translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>Bu&amp;scar:</translation>
    </message>
    <message>
        <source>Please Wait...</source>
        <translation>Espere...</translation>
    </message>
    <message>
        <source>Show Note Bubbles</source>
        <translation>Most. notas flotantes</translation>
    </message>
    <message>
        <source>RDLibrary</source>
        <translation>RDLibrary</translation>
    </message>
    <message>
        <source>Unable to delete audio!</source>
        <translation>¡No puedo eliminar el audio!</translation>
    </message>
    <message>
        <source>Show Only First </source>
        <translation>Mostrar sólo primeros </translation>
    </message>
    <message>
        <source> Matches</source>
        <translation> hallazgos</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow Cart Dragging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">Fin</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Composer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conductor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Publisher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Defined</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation type="unfinished">Audios</translation>
    </message>
    <message>
        <source>Last Cut Played</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enforce Length</source>
        <translation type="unfinished">Forzar duración</translation>
    </message>
    <message>
        <source>Preserve Pitch</source>
        <translation type="unfinished">Preservar pitch</translation>
    </message>
    <message>
        <source>Length Deviation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Owned By</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Talk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run
&amp;Macro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>And Scheduler Code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matching Carts:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecordCut</name>
    <message>
        <source>RDLibrary - Record</source>
        <translation type="obsolete">RDLibrary - Grabar</translation>
    </message>
    <message>
        <source>&amp;Description</source>
        <translation>&amp;Descripción</translation>
    </message>
    <message>
        <source>&amp;Outcue</source>
        <translation>&amp;Outcue</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation type="obsolete">Origen</translation>
    </message>
    <message>
        <source>Weight</source>
        <translation>Peso</translation>
    </message>
    <message>
        <source>Last Played</source>
        <translation>Últ. Reprod</translation>
    </message>
    <message>
        <source># of Plays</source>
        <translation># de reprod</translation>
    </message>
    <message>
        <source>Cut is EVERGREEN</source>
        <translation>Audio es EVERGREEN</translation>
    </message>
    <message>
        <source>Air Date/Time</source>
        <translation>Fecha/hora al aire</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Activado</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactiv.</translation>
    </message>
    <message>
        <source>&amp;Start</source>
        <translation>&amp;Inicio</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <source>Daypart</source>
        <translation>Daypart</translation>
    </message>
    <message>
        <source>&amp;Start Time</source>
        <translation>&amp;Hora de Inicio</translation>
    </message>
    <message>
        <source>End Time</source>
        <translation>Hora de fin</translation>
    </message>
    <message>
        <source>Day of the Week</source>
        <translation>Día de la semana</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Lunes</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Miércoles</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jueves</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Viernes</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>NO SYNC!</source>
        <translation type="obsolete">¡NO SINC.!</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <source>Record Mode</source>
        <translation>Modo grabación</translation>
    </message>
    <message>
        <source>AutoTrim</source>
        <translation>AutoRecortar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>VOX</source>
        <translation>VOX</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Activo</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Desact.</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Esta acción sobreescribirá la grabación existente.
¿Desea continuar?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Vaciar portapapeles</translation>
    </message>
    <message>
        <source>This will empty the clipboard.
Do you still want to proceed?</source>
        <translation>Esta acción vaciará el portapapeles.
¿Aún así desea continuar?</translation>
    </message>
    <message>
        <source>Missing Description</source>
        <translation>Descripción no encontrada</translation>
    </message>
    <message>
        <source>You must provide a Cut Description!</source>
        <translation>¡Debe proveer una descripción para el audio!</translation>
    </message>
    <message>
        <source>Invalid Date</source>
        <translation>Fecha inválida</translation>
    </message>
    <message>
        <source>The Start Date is invalid!</source>
        <translation>¡La fecha de inicio es inválida!</translation>
    </message>
    <message>
        <source>The End Date is invalid!</source>
        <translation>¡La fecha de fin es inválida!</translation>
    </message>
    <message>
        <source>The End Date is prior to the Start Date!</source>
        <translation>La fecha de fin es anterior a la fecha de inicio</translation>
    </message>
    <message>
        <source>The End Date has already passed!
Do you still want to save?</source>
        <translation>¡La fecha de fin ya pasó!
¿Aún así desea guardar la información?</translation>
    </message>
    <message>
        <source>Invalid Time</source>
        <translation>Hora inválida</translation>
    </message>
    <message>
        <source>The Start Time is invalid!</source>
        <translation>¡La hora de inicio es inválida!</translation>
    </message>
    <message>
        <source>The End Time is invalid!</source>
        <translation>¡La hora defin es inválida!</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>No puedo conectarme</translation>
    </message>
    <message>
        <source>Unable to connect to Core AudioEngine</source>
        <translation>No es posible conectarse al Core AudioEngine</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>El audio ya existe</translation>
    </message>
    <message>
        <source>ISRC</source>
        <translation>ISRC</translation>
    </message>
    <message>
        <source>Invalid ISRC</source>
        <translation>ISRC inválido</translation>
    </message>
    <message>
        <source>The ISRC data is malformed or invalid!</source>
        <translation>¡Los datos de ISRC son inválidos o mal formados!</translation>
    </message>
    <message>
        <source>The StartTime cannot be the same as the End Time!</source>
        <translation>¡La hora de inicio no puede ser la misma que la de fin!</translation>
    </message>
    <message>
        <source>Set All</source>
        <translation>Selec. todo</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Quita todo</translation>
    </message>
    <message>
        <source>&amp;ISCI Code</source>
        <translation>Código &amp;ISCI</translation>
    </message>
    <message>
        <source>AES ALARM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ingest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Info / Record</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
